#
#############################################################
# FULL BACKUP Utility for ENIGMA2
# Version 2.0 - 14-04-2011
# supports USB-HDD-NAS Backup
#############################################################
#
#!/bin/sh

VERSION="Version 2.0 - 14.04.2011"
DIRECTORY=$1
if [ -f /proc/stb/info/boxtype ] ; then
	MODEL=$( cat /proc/stb/info/boxtype )
	if grep et /proc/stb/info/boxtype > /dev/null ; then
		TYPE=ET
		MTDROOT=3
		MTDBOOT=2
	else
		echo "No modeltype found"
		echo "Please update drivers"
		exit 0
	fi

elif [ -f /proc/stb/info/vumodel ] ; then
	MODEL=$( cat /proc/stb/info/vumodel )
	TYPE=VU 
	MTDROOT=0
	MTDBOOT=2
else	
	echo "BOXTYPE not found"
	echo "please update drivers"
	exit 0
fi



echo "_________________________________________________"
echo " "
echo  "USB Backup Tool for $MODEL - $VERSION"
echo "_________________________________________________"
echo " "
echo "Please be patience, a backup will now be made,"
echo "this will take approximately 2 minutes "
echo "_________________________________________________"

DATE=`date +%Y%m%d_%H%M%S`
IMAGEVERSION=`date +%Y%m%d`
MKFS=/usr/bin/mkfs.jffs2
BUILDIMAGE=/usr/bin/buildimage
NANDDUMP=/usr/bin/nanddump
EXTRA=$DIRECTORY/fullbackup_$MODEL/$DATE

if [ ! -f $MKFS ] ; then
	echo $MKFS" not found"
	exit 0
fi

if [ ! -f $BUILDIMAGE ] ; then
	echo $BUILDIMAGE" not found"
	exit 0
fi

if [ ! -f $NANDDUMP ] ; then
	echo $NANDDUMP" not found"
	exit 0
fi

rm -rf $DIRECTORY/bi
mkdir -p $DIRECTORY/bi
mkdir -p /tmp/bi/boot
mkdir -p /tmp/bi/root

mount -t jffs2 /dev/mtdblock$MTDBOOT /tmp/bi/boot
mount -t jffs2 /dev/mtdblock$MTDROOT /tmp/bi/root

if [ -s $BUILDIMAGE ] ; then
	echo "Create boot.jffs2"
	$MKFS --root=/tmp/bi/boot --faketime --output=$DIRECTORY/bi/boot.jffs2 $OPTIONS
	echo "Create root.jffs2"
	$MKFS --root=/tmp/bi/root --faketime --output=$DIRECTORY/bi/root.jffs2 $OPTIONS
fi

echo "Create kerneldump"
sleep 2

nanddump /dev/mtd1 -o -b > $DIRECTORY/bi/vmlinux.gz

echo "_________________________________________________"
echo " "
echo "Creating $MODEL USB-Backup Image"
echo "_________________________________________________"

if [ $TYPE = "ET" ] ; then
	mkdir -p $DIRECTORY/$MODEL
	mkdir -p $EXTRA
	mv $DIRECTORY/bi/root.jffs2 $DIRECTORY/$MODEL/rootfs.bin
	mv $DIRECTORY/bi/boot.jffs2 $DIRECTORY/$MODEL/boot.bin
	mv $DIRECTORY/bi/vmlinux.gz $DIRECTORY/$MODEL/kernel.bin
	echo "rename this file to 'force' to force an update without confirmation" > $DIRECTORY/$MODEL/noforce;
	echo $MODEL-$IMAGEVERSION > $DIRECTORY/$MODEL/imageversion;
	cp -r $DIRECTORY/$MODEL $EXTRA/$MODEL #copy the made back-up to images

	if [ -f $DIRECTORY/$MODEL/rootfs.bin -a -f $DIRECTORY/$MODEL/boot.bin -a -f $DIRECTORY/$MODEL/kernel.bin -a -f $DIRECTORY/$MODEL/imageversion -a -f $DIRECTORY/$MODEL/noforce ] ; then
		echo "_________________________________________________"
		echo " "
		echo "USB Image created on:" $DIRECTORY"/$MODEL "
		echo "and there is made an extra copy on:" 
		echo $EXTRA"/$MODEL"
		echo "_________________________________________________"	

		echo " "
		if [ $MODEL = "et9000" ] ; then
			echo "To restore the image: "
			echo "Place the USB-stick in the front USB-port and switch"
			echo "the $MODEL off and on with the powerswitch on the back"
			echo "of the $MODEL"
			echo "Follow the instructions on front-display."
		
		elif [ $MODEL = "et5000" ] ; then
			echo "To restore the image: "
			echo "Place the USB-stick in the front USB-port and switch"
			echo "the $MODEL off and on with the powerswitch on the back"
			echo "of the $MODEL"
			echo "Press arrow up from frontpanel to start loading."
		else
			echo "Please look at the manual how to update the image"
		fi
	else
		echo "Image creation failed - "
		echo "e.g. wrong backup destination or"
		echo "no space left on backup device"

	fi

elif [ $TYPE = "VU" ] ; then
	mkdir -p $DIRECTORY/vuplus/$MODEL
	mkdir -p $EXTRA/vuplus
	mv $DIRECTORY/bi/root.jffs2 $DIRECTORY/vuplus/$MODEL/root_cfe_auto.jffs2
	mv $DIRECTORY/bi/boot.jffs2 $DIRECTORY/vuplus/$MODEL/boot_cfe_auto.jffs2
	mv $DIRECTORY/bi/vmlinux.gz $DIRECTORY/vuplus/$MODEL/kernel_cfe_auto.bin
	cp -r $DIRECTORY/vuplus/$MODEL $EXTRA/vuplus/$MODEL #copy the made back-up to images

	if [ -f $DIRECTORY/vuplus/$MODEL/root_cfe_auto.jffs2 -a -f $DIRECTORY/vuplus/$MODEL/boot_cfe_auto.jffs2 -a -f $DIRECTORY/vuplus/$MODEL/kernel_cfe_auto.bin ] ; then
		echo "_________________________________________________"
		echo " "
		echo "USB Image created on:" $DIRECTORY"/vuplus/$MODEL "
		echo "and there is made an extra copy on:" 
		echo $EXTRA"/vuplus/$MODEL"
		echo "_________________________________________________"	

		echo " "
		if [ $MODEL = "vuduo" ] ; then
			echo "To restore the image: "
			echo "Place the USB-stick in the front USB-port and switch"
			echo "the $MODEL off and on with the powerswitch on the back"
			echo "of the $MODEL"
			echo "The image will be load automatically."
		
		else
			echo "Please look at the manual how to update the image"
		fi
	else
		echo "Image creation failed - "
		echo "e.g. wrong backup destination or"
		echo "no space left on backup device"

	fi

fi

 umount /tmp/bi/root
 umount /tmp/bi/boot
 rm -rf /tmp/bi
 rm -rf $DIRECTORY/bi

exit 0